@@ -2,16 +2,16 @@
 
 from __future__ import annotations
 
-import asyncio
 from collections.abc import Callable
 from functools import wraps
+import inspect
 import logging
 from time import monotonic
 from typing import Any, Final, ParamSpec, TypeVar, cast
 
 from hahomematic.context import IN_SERVICE_VAR
 from hahomematic.exceptions import BaseHomematicException
-from hahomematic.support import reduce_args
+from hahomematic.support import extract_exc_args
 
 P = ParamSpec("P")
 R = TypeVar("R")
@@ -54,13 +54,13 @@ def inspector(  # noqa: C901
 
         """
 
-        def handle_exception(ex: Exception, func: Callable, is_sub_service_call: bool, is_homematic: bool) -> R:
+        def handle_exception(exc: Exception, func: Callable, is_sub_service_call: bool, is_homematic: bool) -> R:
             """Handle exceptions for decorated functions."""
             if not is_sub_service_call and log_level > logging.NOTSET:
-                message = f"{func.__name__.upper()} failed: {reduce_args(args=ex.args)}"
+                message = f"{func.__name__.upper()} failed: {extract_exc_args(exc=exc)}"
                 logging.getLogger(func.__module__).log(level=log_level, msg=message)
             if re_raise or not is_homematic:
-                raise ex
+                raise exc
             return cast(R, no_raise_return)
 
         @wraps(func)
@@ -71,14 +71,18 @@ def inspector(  # noqa: C901
             token = IN_SERVICE_VAR.set(True) if not IN_SERVICE_VAR.get() else None
             try:
                 return_value: R = func(*args, **kwargs)
-            except BaseHomematicException as bhe:
+            except BaseHomematicException as bhexc:
                 if token:
                     IN_SERVICE_VAR.reset(token)
-                return handle_exception(ex=bhe, func=func, is_sub_service_call=IN_SERVICE_VAR.get(), is_homematic=True)
-            except Exception as ex:
+                return handle_exception(
+                    exc=bhexc, func=func, is_sub_service_call=IN_SERVICE_VAR.get(), is_homematic=True
+                )
+            except Exception as exc:
                 if token:
                     IN_SERVICE_VAR.reset(token)
-                return handle_exception(ex=ex, func=func, is_sub_service_call=IN_SERVICE_VAR.get(), is_homematic=False)
+                return handle_exception(
+                    exc=exc, func=func, is_sub_service_call=IN_SERVICE_VAR.get(), is_homematic=False
+                )
             else:
                 if token:
                     IN_SERVICE_VAR.reset(token)
@@ -95,14 +99,18 @@ def inspector(  # noqa: C901
             token = IN_SERVICE_VAR.set(True) if not IN_SERVICE_VAR.get() else None
             try:
                 return_value = await func(*args, **kwargs)  # type: ignore[misc]  # Await the async call
-            except BaseHomematicException as bhe:
+            except BaseHomematicException as bhexc:
                 if token:
                     IN_SERVICE_VAR.reset(token)
-                return handle_exception(ex=bhe, func=func, is_sub_service_call=IN_SERVICE_VAR.get(), is_homematic=True)
-            except Exception as ex:
+                return handle_exception(
+                    exc=bhexc, func=func, is_sub_service_call=IN_SERVICE_VAR.get(), is_homematic=True
+                )
+            except Exception as exc:
                 if token:
                     IN_SERVICE_VAR.reset(token)
-                return handle_exception(ex=ex, func=func, is_sub_service_call=IN_SERVICE_VAR.get(), is_homematic=False)
+                return handle_exception(
+                    exc=exc, func=func, is_sub_service_call=IN_SERVICE_VAR.get(), is_homematic=False
+                )
             else:
                 if token:
                     IN_SERVICE_VAR.reset(token)
@@ -112,7 +120,7 @@ def inspector(  # noqa: C901
                     _log_performance_message(func, start, *args, **kwargs)
 
         # Check if the function is a coroutine or not and select the appropriate wrapper
-        if asyncio.iscoroutinefunction(func):
+        if inspect.iscoroutinefunction(func):
             setattr(wrap_async_function, "ha_service", True)
             return wrap_async_function  # type: ignore[return-value]
         setattr(wrap_sync_function, "ha_service", True)
@@ -175,6 +183,6 @@ def measure_execution_time[CallableT: Callable[..., Any]](func: CallableT) -> Ca
             if start:
                 _log_performance_message(func, start, *args, **kwargs)
 
-    if asyncio.iscoroutinefunction(func):
+    if inspect.iscoroutinefunction(func):
         return async_measure_wrapper  # type: ignore[return-value]
     return measure_wrapper  # type: ignore[return-value]
