@@ -24,7 +24,11 @@ _LOGGER: Final = logging.getLogger(__name__)
 class BaseClimateSensor[SensorT: float | None](CalculatedDataPoint[SensorT]):
     """Implementation of a calculated climate sensor."""
 
-    __slots__ = ("_type",)
+    __slots__ = (
+        "_dp_temperature",
+        "_dp_humidity",
+        "_dp_wind_speed",
+    )
 
     _category = DataPointCategory.SENSOR
 
@@ -60,7 +64,7 @@ class BaseClimateSensor[SensorT: float | None](CalculatedDataPoint[SensorT]):
 class ApparentTemperature(BaseClimateSensor):
     """Implementation of a calculated sensor for apparent temperature."""
 
-    __slots__ = ("_unit",)
+    __slots__ = ()
 
     _calculated_parameter = CalulatedParameter.APPARENT_TEMPERATURE
 
@@ -110,7 +114,7 @@ class ApparentTemperature(BaseClimateSensor):
 class DewPoint(BaseClimateSensor):
     """Implementation of a calculated sensor for dew point."""
 
-    __slots__ = ("_unit",)
+    __slots__ = ()
 
     _calculated_parameter = CalulatedParameter.DEW_POINT
 
@@ -138,7 +142,7 @@ class DewPoint(BaseClimateSensor):
 class FrostPoint(BaseClimateSensor):
     """Implementation of a calculated sensor for frost point."""
 
-    __slots__ = ("_unit",)
+    __slots__ = ()
 
     _calculated_parameter = CalulatedParameter.FROST_POINT
 
@@ -168,7 +172,7 @@ class FrostPoint(BaseClimateSensor):
 class VaporConcentration(BaseClimateSensor):
     """Implementation of a calculated sensor for vapor concentration."""
 
-    __slots__ = ("_unit",)
+    __slots__ = ()
 
     _calculated_parameter = CalulatedParameter.VAPOR_CONCENTRATION
 
