@@ -5,7 +5,7 @@ from __future__ import annotations
 import asyncio
 from collections.abc import Callable, Mapping
 from datetime import datetime
-from functools import cached_property, partial
+from functools import partial
 import logging
 import os
 import random
@@ -51,7 +51,7 @@ from hahomematic.exceptions import BaseHomematicException, HaHomematicException
 from hahomematic.model.calculated import CalculatedDataPoint
 from hahomematic.model.custom import data_point as hmce, definition as hmed
 from hahomematic.model.data_point import BaseParameterDataPoint, CallbackDataPoint
-from hahomematic.model.decorators import info_property, state_property
+from hahomematic.model.decorators import cached_slot_property, info_property, state_property
 from hahomematic.model.event import GenericEvent
 from hahomematic.model.generic import GenericDataPoint
 from hahomematic.model.support import (
@@ -65,10 +65,10 @@ from hahomematic.model.update import DpUpdate
 from hahomematic.support import (
     CacheEntry,
     check_or_create_directory,
+    extract_exc_args,
     get_channel_address,
     get_channel_no,
     get_rx_modes,
-    reduce_args,
 )
 
 __all__ = ["Channel", "Device"]
@@ -79,6 +79,36 @@ _LOGGER: Final = logging.getLogger(__name__)
 class Device(PayloadMixin):
     """Object to hold information about a device and associated data points."""
 
+    __slots__ = (
+        "_address",
+        "_cached_relevant_for_central_link_management",
+        "_central",
+        "_channel_groups",
+        "_channels",
+        "_client",
+        "_description",
+        "_device_updated_callbacks",
+        "_firmware_update_callbacks",
+        "_forced_availability",
+        "_has_custom_data_point_definition",
+        "_id",
+        "_ignore_for_custom_data_point",
+        "_ignore_on_initial_load",
+        "_interface",
+        "_interface_id",
+        "_is_updatable",
+        "_manufacturer",
+        "_model",
+        "_modified_at",
+        "_name",
+        "_product_group",
+        "_rooms",
+        "_rx_modes",
+        "_sub_model",
+        "_update_data_point",
+        "_value_cache",
+    )
+
     def __init__(self, central: hmcu.CentralUnit, interface_id: str, device_address: str) -> None:
         """Initialize the device object."""
         PayloadMixin.__init__(self)
@@ -377,18 +407,18 @@ class Device(PayloadMixin):
     @inspector()
     async def create_central_links(self) -> None:
         """Create a central links to support press events on all channels with click events."""
-        if self.relevant_for_central_link_management:
+        if self.relevant_for_central_link_management:  # pylint: disable=using-constant-test
             for channel in self._channels.values():
                 await channel.create_central_link()
 
     @inspector()
     async def remove_central_links(self) -> None:
         """Remove central links."""
-        if self.relevant_for_central_link_management:
+        if self.relevant_for_central_link_management:  # pylint: disable=using-constant-test
             for channel in self._channels.values():
                 await channel.remove_central_link()
 
-    @cached_property
+    @cached_slot_property
     def relevant_for_central_link_management(self) -> bool:
         """Return if channel is relevant for central link management."""
         return (
@@ -537,8 +567,8 @@ class Device(PayloadMixin):
         try:
             device_exporter = _DefinitionExporter(device=self)
             await device_exporter.export_data()
-        except Exception as ex:
-            raise HaHomematicException(f"EXPORT_DEVICE_DEFINITION failed: {reduce_args(args=ex.args)}") from ex
+        except Exception as exc:
+            raise HaHomematicException(f"EXPORT_DEVICE_DEFINITION failed: {extract_exc_args(exc=exc)}") from exc
 
     def refresh_firmware_data(self) -> None:
         """Refresh firmware data of the device."""
@@ -614,8 +644,8 @@ class Device(PayloadMixin):
         for callback_handler in self._device_updated_callbacks:
             try:
                 callback_handler(*args)
-            except Exception as ex:
-                _LOGGER.warning("FIRE_DEVICE_UPDATED failed: %s", reduce_args(args=ex.args))
+            except Exception as exc:
+                _LOGGER.warning("FIRE_DEVICE_UPDATED failed: %s", extract_exc_args(exc=exc))
 
     def __str__(self) -> str:
         """Provide some useful information."""
@@ -632,6 +662,29 @@ class Device(PayloadMixin):
 class Channel(PayloadMixin):
     """Object to hold information about a channel and associated data points."""
 
+    __slots__ = (
+        "_address",
+        "_calculated_data_points",
+        "_central",
+        "_custom_data_point",
+        "_description",
+        "_device",
+        "_function",
+        "_generic_data_points",
+        "_generic_events",
+        "_group_master",
+        "_group_no",
+        "_id",
+        "_is_in_multi_group",
+        "_modified_at",
+        "_name_data",
+        "_no",
+        "_paramset_keys",
+        "_rooms",
+        "_type_name",
+        "_unique_id",
+    )
+
     def __init__(self, device: Device, channel_address: str) -> None:
         """Initialize the channel object."""
         PayloadMixin.__init__(self)
@@ -843,8 +896,8 @@ class Channel(PayloadMixin):
                     and key == REPORT_VALUE_USAGE_VALUE_ID
                     and value > 0
                 )
-        except BaseHomematicException as bhe:
-            _LOGGER.debug("HAS_CENTRAL_LINK failed: %s", reduce_args(args=bhe.args))
+        except BaseHomematicException as bhexc:
+            _LOGGER.debug("HAS_CENTRAL_LINK failed: %s", extract_exc_args(exc=bhexc))
         return False
 
     async def _has_program_ids(self) -> bool:
@@ -1009,6 +1062,12 @@ class Channel(PayloadMixin):
 class _ValueCache:
     """A Cache to temporarily stored values."""
 
+    __slots__ = (
+        "_device",
+        "_device_cache",
+        "_sema_get_or_load_value",
+    )
+
     _NO_VALUE_CACHE_ENTRY: Final = "NO_VALUE_CACHE_ENTRY"
 
     def __init__(self, device: Device) -> None:
@@ -1023,12 +1082,12 @@ class _ValueCache:
         try:
             for data_point in self._get_base_data_points():
                 await data_point.load_data_point_value(call_source=CallSource.HM_INIT)
-        except BaseHomematicException as ex:
+        except BaseHomematicException as bhexc:
             _LOGGER.debug(
                 "init_base_data_points: Failed to init cache for channel0 %s, %s [%s]",
                 self._device.model,
                 self._device.address,
-                ex,
+                extract_exc_args(exc=bhexc),
             )
 
     def _get_base_data_points(self) -> set[GenericDataPoint]:
@@ -1049,12 +1108,12 @@ class _ValueCache:
         try:
             for event in self._get_readable_events():
                 await event.load_data_point_value(call_source=CallSource.HM_INIT)
-        except BaseHomematicException as ex:
+        except BaseHomematicException as bhexc:
             _LOGGER.debug(
                 "init_base_events: Failed to init cache for channel0 %s, %s [%s]",
                 self._device.model,
                 self._device.address,
-                ex,
+                extract_exc_args(exc=bhexc),
             )
 
     def _get_readable_events(self) -> set[GenericEvent]:
@@ -1091,14 +1150,14 @@ class _ValueCache:
                     paramset_key=paramset_key,
                     parameter=parameter,
                 )
-            except BaseHomematicException as ex:
+            except BaseHomematicException as bhexc:
                 _LOGGER.debug(
                     "GET_OR_LOAD_VALUE: Failed to get data for %s, %s, %s, %s: %s",
                     self._device.model,
                     channel_address,
                     parameter,
                     call_source,
-                    reduce_args(args=ex.args),
+                    extract_exc_args(exc=bhexc),
                 )
             for d_parameter, d_value in value_dict.items():
                 self._add_entry_to_device_cache(
@@ -1185,6 +1244,15 @@ class _ValueCache:
 class _DefinitionExporter:
     """Export device definitions from cache."""
 
+    __slots__ = (
+        "_central",
+        "_client",
+        "_device_address",
+        "_interface_id",
+        "_random_id",
+        "_storage_folder",
+    )
+
     def __init__(self, device: Device) -> None:
         """Init the device exporter."""
         self._client: Final = device.client
